@@ -2,7 +2,6 @@ from django import forms
 from edc_consent.form_validators import ConsentFormValidatorMixin
 from edc_constants.constants import FEMALE, MALE, NO, OTHER, PENDING, POS, YES
 from edc_form_validators import FormValidator
-from edc_model import estimated_date_from_ago
 from edc_utils.forms import EstimatedDateFromAgoFormMixin
 
 
@@ -12,7 +11,7 @@ class SubjectScreeningFormValidator(
     def clean(self) -> None:
         self.get_consent_for_period_or_raise(self.cleaned_data.get("report_datetime"))
         self.validate_age()
-        self.validate_hiv_dx()
+        self.validate_hiv()
         self.validate_cd4()
         self.validate_serum_crag()
         self.validate_lp_and_csf_crag()
@@ -23,30 +22,13 @@ class SubjectScreeningFormValidator(
             YES, field="unsuitable_for_study", field_required="reasons_unsuitable"
         )
 
-    def validate_hiv_dx(self):
-        self.not_required_if(
-            NO,
+    def validate_hiv(self):
+        self.required_if(
+            YES,
             field="hiv_pos",
-            field_required="hiv_dx_ago",
-            inverse=False,
+            field_required="hiv_confirmed_date",
         )
-        self.not_required_if(
-            NO,
-            field="hiv_pos",
-            field_required="hiv_dx_date",
-            inverse=False,
-        )
-        if self.cleaned_data.get("hiv_pos") == YES and not (
-            self.cleaned_data.get("hiv_dx_ago") or self.cleaned_data.get("hiv_dx_date")
-        ):
-            raise forms.ValidationError(
-                {"hiv_dx_date": "This field is required (or the above)."}
-            )
-
-        self.raise_if_both_ago_and_actual_date(
-            ago_field="hiv_dx_ago", date_field="hiv_dx_date", label="HIV diagnosis"
-        )
-        self.applicable_if(YES, field="hiv_pos", field_applicable="hiv_dx_new")
+        self.applicable_if(YES, field="hiv_pos", field_applicable="hiv_confirmed_method")
 
     def validate_cd4(self) -> None:
         if self.cleaned_data.get("cd4_date") and self.cleaned_data.get("report_datetime"):
@@ -194,9 +176,3 @@ class SubjectScreeningFormValidator(
             other_specify_field="any_other_mg_ssx_other",
             other_stored_value=YES,
         )
-
-    @property
-    def provided_hiv_dx_date(self):
-        if self.cleaned_data.get("hiv_dx_ago"):
-            return estimated_date_from_ago(data=self.cleaned_data, ago_field="hiv_dx_ago")
-        return self.cleaned_data.get("hiv_dx_date")
