@@ -1,6 +1,6 @@
 from typing import Any
 
-from edc_constants.constants import YES
+from edc_constants.constants import POS, YES
 from edc_crf.crf_form_validator import CrfFormValidator
 
 
@@ -9,6 +9,9 @@ class HistopathologyFormValidatorMixin:
         self.required_if(
             YES, field="tissue_biopsy_performed", field_required="tissue_biopsy_date"
         )
+
+        self.validate_date_against_report_datetime("tissue_biopsy_date")
+
         self.applicable_if(
             YES,
             field="tissue_biopsy_performed",
